==> nextcloud-app-contacts-2.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/sr.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Download" : "Преузми",
    "Copy link" : "Копирај везу",
    "Click to copy the link to your clipboard" : "Кликните на везу испод да је копирате",
    "Toggle sharing" : "Укључи/искључи дељење",
    "Delete" : "Обриши",
    "Rename" : "Преименуј",
    "Share with users or groups" : "Дели са корисницима или групама",
    "can edit" : "може да мења",
    "Close" : "Затвори",
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
    "Address book name" : "Име адресара",
    "Only these special characters are allowed: -_.!?#|()" : "Само ови специјални карактери су дозвољени: -_.!?#|()",
    "Address book could not be created." : "Адресар не може да се креира.",
    "The selected image is too big (max 1MB)" : "Изабрана слика је превелика (макс 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Овај контакт је оштећен и сад је поправљен. Проверите податке и снимите га ако желите да запамтите ове измене.",
    "No contacts in here" : "Овде нема контаката",
    "Name" : "Назив",
    "Organization" : "Организација",
    "Title" : "Титула",
    "Add field …" : "Додај поље …",
    "Save changes" : "Сними измене",
    "Address book" : "Адресар",
    "Loading contacts …" : "Учитавам контакте …",
    "Import into" : "Увези у",
    "Importing..." : "Увозим...",
    "Select your addressbook" : "Одаберите Ваш адресар",
    "No search result for {query}" : "Није нађен ниједан резултат за претрагу {query}",
    "All contacts" : "Сви контакти",
    "Post office box" : "Поштанско сандуче",
    "Postal code" : "Поштански број",
    "City" : "Место",
    "State or province" : "Покрајина или провинција",
    "Country" : "Држава",
    "Address" : "Адреса",
    "(new group)" : "(нова група)",
    "Last name" : "Презиме",
    "First name" : "Име",
    "Additional names" : "Додатна имена",
    "Prefix" : "Префикс",
    "Suffix" : "Суфикс",
    "Importing into" : "Увозим у",
    "New contact" : "Нови контакт",
    "Not grouped" : "Негруписани",
    "Sort by" : "Сортирај по",
    "{addressbook} shared by {owner}" : "{addressbook} поделио {owner}",
    "Contact not found." : "Контакт није нађен.",
    "You don't have permission to write to this addressbook." : "Немате дозволе да уписујете у овај адресар.",
    "Contact could not be created." : "Контакт не може да се направи.",
    "No contacts in file. Only vCard files are allowed." : "Нема контаката у фајлу. Дозвољени су само vCard фајлови.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Подржани су само vCard верзија 4.0 (RFC6350) и верзија 3.0 (RFC2426).",
    "Contact could not be saved." : "Не могу да сачувам контакт.",
    "Waiting for the server to be ready..." : "Чекам да сервер буде спреман...",
    "Display name" : "Име за приказ",
    "Nickname" : "Надимак",
    "Detailed name" : "Пуно име",
    "Notes" : "Белешке",
    "Website" : "Вебсајт",
    "Federated Cloud ID" : "ИД Здруженог облака",
    "Home" : "Кућа",
    "Work" : "Посао",
    "Other" : "Остало",
    "Groups" : "Групе",
    "Birthday" : "Рођендан",
    "Anniversary" : "Годишњица",
    "Date of death" : "Датум смрти",
    "Email" : "Е-пошта",
    "Instant messaging" : "Брзе поруке",
    "Phone" : "Телефон",
    "Mobile" : "Мобилни",
    "Fax" : "Факс",
    "Fax home" : "Факс кућа",
    "Fax work" : "Факс посао",
    "Pager" : "Пејџер",
    "Voice" : "Гласовна пошта",
    "Social network" : "Социјална мрежа",
    "Relationship" : "Однос",
    "Spouse" : "Супруга",
    "Child" : "Дете",
    "Mother" : "Мајка",
    "Father" : "Отац",
    "Parent" : "Родитељ",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родбина",
    "Friend" : "Пријатељ",
    "Colleague" : "Колега",
    "Manager" : "Менаџер",
    "Assistant" : "Асистент",
    "Gender" : "Пол",
    "Female" : "Женски",
    "Male" : "Мушки",
    "Details" : "Детаљи",
    "Settings" : "Поставке"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-contacts-2.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/sr.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Контакти",
    "Download" : "Преузми",
    "Copy link" : "Копирај везу",
    "Click to copy the link to your clipboard" : "Кликните на везу испод да је копирате",
    "Toggle sharing" : "Укључи/искључи дељење",
    "Delete" : "Обриши",
    "Rename" : "Преименуј",
    "Share with users or groups" : "Дели са корисницима или групама",
    "can edit" : "може да мења",
    "Close" : "Затвори",
    "Enabled" : "Укључено",
    "Disabled" : "Искључено",
    "Copied!" : "Копирано!",
    "Not supported!" : "Није подржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за копирање.",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за копирање.",
    "Address book name" : "Име адресара",
    "Only these special characters are allowed: -_.!?#|()" : "Само ови специјални карактери су дозвољени: -_.!?#|()",
    "Address book could not be created." : "Адресар не може да се креира.",
    "The selected image is too big (max 1MB)" : "Изабрана слика је превелика (макс 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Овај контакт је оштећен и сад је поправљен. Проверите податке и снимите га ако желите да запамтите ове измене.",
    "No contacts in here" : "Овде нема контаката",
    "Name" : "Назив",
    "Organization" : "Организација",
    "Title" : "Титула",
    "Add field …" : "Додај поље …",
    "Save changes" : "Сними измене",
    "Address book" : "Адресар",
    "Loading contacts …" : "Учитавам контакте …",
    "Import into" : "Увези у",
    "Importing..." : "Увозим...",
    "Select your addressbook" : "Одаберите Ваш адресар",
    "Import is disabled because no writable address book had been found." : "Увоз је искључен зато што није нађен ниједан адресар у који може да се пише.",
    "No search result for {query}" : "Није нађен ниједан резултат за претрагу {query}",
    "All contacts" : "Сви контакти",
    "Post office box" : "Поштанско сандуче",
    "Postal code" : "Поштански број",
    "City" : "Место",
    "State or province" : "Покрајина или провинција",
    "Country" : "Држава",
    "Address" : "Адреса",
    "(new group)" : "(нова група)",
    "Last name" : "Презиме",
    "First name" : "Име",
    "Additional names" : "Додатна имена",
    "Prefix" : "Префикс",
    "Suffix" : "Суфикс",
    "Importing into" : "Увозим у",
    "New contact" : "Нови контакт",
    "Not grouped" : "Негруписани",
    "Sort by" : "Сортирај по",
    "There is no address book available to create a contact." : "Нема адресара у коме може да се креира нови контакт.",
    "{addressbook} shared by {owner}" : "{addressbook} поделио {owner}",
    "Contact not found." : "Контакт није нађен.",
    "You don't have permission to write to this addressbook." : "Немате дозволе да уписујете у овај адресар.",
    "Contact could not be created." : "Контакт не може да се направи.",
    "No contacts in file. Only vCard files are allowed." : "Нема контаката у фајлу. Дозвољени су само vCard фајлови.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Подржани су само vCard верзија 4.0 (RFC6350) и верзија 3.0 (RFC2426).",
    "Contact could not be moved." : "Контакт не може да се премести.",
    "Contact could not be saved." : "Не могу да сачувам контакт.",
    "Waiting for the server to be ready…" : "Чекам да сервер буде спреман…",
    "Importing…" : "Увозим…",
    "Display name" : "Име за приказ",
    "Nickname" : "Надимак",
    "Detailed name" : "Пуно име",
    "Notes" : "Белешке",
    "Website" : "Вебсајт",
    "Federated Cloud ID" : "ИД Здруженог облака",
    "Home" : "Кућа",
    "Work" : "Посао",
    "Other" : "Остало",
    "Groups" : "Групе",
    "Birthday" : "Рођендан",
    "Anniversary" : "Годишњица",
    "Date of death" : "Датум смрти",
    "Email" : "Е-пошта",
    "Instant messaging" : "Брзе поруке",
    "Phone" : "Телефон",
    "Mobile" : "Мобилни",
    "Work mobile" : "Пословни мобилни",
    "Fax" : "Факс",
    "Fax home" : "Факс кућа",
    "Fax work" : "Факс посао",
    "Pager" : "Пејџер",
    "Voice" : "Гласовна пошта",
    "Car" : "Кола",
    "Work pager" : "Пословни пејџер",
    "Social network" : "Социјална мрежа",
    "Relationship" : "Однос",
    "Spouse" : "Супруга",
    "Child" : "Дете",
    "Mother" : "Мајка",
    "Father" : "Отац",
    "Parent" : "Родитељ",
    "Brother" : "Брат",
    "Sister" : "Сестра",
    "Relative" : "Родбина",
    "Friend" : "Пријатељ",
    "Colleague" : "Колега",
    "Manager" : "Менаџер",
    "Assistant" : "Асистент",
    "Gender" : "Пол",
    "Female" : "Женски",
    "Male" : "Мушки",
    "Details" : "Детаљи",
    "Settings" : "Поставке"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
